@@ -39,12 +39,9 @@ void 			ev_gui_menu_position_tree_selection (GtkMenu   *menu,
 
 gint 			get_num_monitors (GtkWindow * window);
 
-gdouble 		get_screen_dpi (GtkWindow * window);
-
 void           		file_chooser_dialog_add_writable_pixbuf_formats (GtkFileChooser *chooser);
 GdkPixbufFormat* 	get_gdk_pixbuf_format_by_extension (gchar *uri);
 
-char*			escape_uri_for_display (const char *uri);
 G_END_DECLS
 
 #endif /* __EV_VIEW_H__ */
